@@ -2,8 +2,8 @@ import math
 
 import torch
 from torch import nn
-from torch.nn import init
 
+from . import init
 from .. import functional as C
 
 Tensor = torch.Tensor
@@ -19,19 +19,16 @@ class ComplexLinear(nn.Module):
         self.weight_imag = nn.Parameter(torch.Tensor(out_features, in_features))
         if bias:
             self.bias = nn.Parameter(torch.Tensor(2 * out_features))
-            # self.bias_imag = nn.Parameter(torch.Tensor(out_features))
         else:
             self.bias = self.register_parameter("bias", None)
-            # self.bias_imag = self.register_parameter("bias_imag", None)
         self.reset_parameters()
 
     def reset_parameters(self):
-        init.kaiming_uniform_(self.weight_real, a=math.sqrt(5))
-        init.kaiming_uniform_(self.weight_imag, a=math.sqrt(5))
+        init.rayleigh_kaiming_(self.weight_real, self.weight_imag)
         if self.bias is not None:
-            fan_in, _ = init._calculate_fan_in_and_fan_out(self.weight_real)
+            fan_in, _ = nn.init._calculate_fan_in_and_fan_out(self.weight_real)
             bound = 1 / math.sqrt(fan_in)
-            init.uniform_(self.bias, -bound, bound)
+            nn.init.uniform_(self.bias, -bound, bound)
 
     def forward(self, x: Tensor) -> Tensor:
         return C.complex_linear(x, self.weight_real, self.weight_imag, self.bias)
